/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.domain.sgdCommunication;

import java.util.stream.Stream;

public enum SgdVectorClassifier {
    // Initiale Schlüsselableitung oder Schlüsselableitung durch Kontoinhaber
    R1,
    // Schlüsselableitung für oder durch einen Berechtigungsempfänger
    R2,
    // Schlüsselableitung für oder durch einen Empfänger durch einen Vertreter
    R3;

    public static SgdVectorClassifier getClassificationFromVector(String vector) {
        return Stream.of(SgdVectorClassifier.values())
                .filter(sgdVectorClassifier -> vector.startsWith(sgdVectorClassifier.getPrintableClassifier()))
                .findAny()
                .orElseThrow(() -> new RuntimeException("Could not get SgdVectorClassifier for vector '" + vector + "'!"));
    }

    public String getPrintableClassifier() {
        return this.name().toLowerCase();
    }
}
